@@ -2,10 +2,10 @@ import numpy as np
 from sklearn.metrics import confusion_matrix
 import matplotlib.pyplot as plt
 import matplotlib as mpl
-from nn2.data import TabularDataset
-from nn2.etc import *
 from IPython.display import display
 import sklearn
+from dl2050nn.etc import *
+from dl2050nn.data import TabularDataset
 # https://en.wikipedia.org/wiki/Sensitivity_and_specificity
 
 epsilon = 1e-9
